#!/usr/bin/env python

from simplex import *
import sys, time

def from_index_record(convert, record):
    values = record.split("\t")
    key = convert(values[:-1])
    pos = int(values[-1])
    return key, pos

try:
    separator = sys.argv.index("--")
    filename, numeric, index_filename = sys.argv[1:4]
    fields = map(int, sys.argv[4:separator])
    terms = groups(sys.argv[separator+1:], len(fields))
    numeric = numeric == "true"
except (IndexError, ValueError):
    print >>sys.stderr, "Usage: %s <filename> <numeric> <index> <field>... -- <term value>..." % sys.argv[0]
    sys.exit(1)

f = open(filename)
fi = open(index_filename)
accessor = DelimitedRecord(fields, numeric=numeric)

try:
    t = time.time()
    l = [from_index_record(accessor.convert, record) for record in fi]
    print >>sys.stderr, "Read index (at %s seconds, with %d entries)." % (time.time() - t, len(l))

    # Now use the index.

    index = IndexedFile(f, l, accessor.get_key)

    for term in terms:

        # Convert the term to the appropriate type.

        term = accessor.convert(term)

        # Perform the search.

        t = time.time()
        lines = index.find(term)
        if lines:
            print >>sys.stderr, "Found (at %s seconds)..." % (time.time() - t)
            for line in lines:
                sys.stdout.write(line)

finally:
    f.close()
    fi.close()

# vim: tabstop=4 expandtab shiftwidth=4
